function varargout=plotKuhnDecomposition(d,varargin)
  assert(ismember(d,1:3))
  p = inputParser; 
  p.addParamValue('order',1);
  p.addParamValue('vcolor','k'); % vertices color
  p.addParamValue('vsize',70); % 
  p.addParamValue('ncolor','DarkSlateGray'); % nodes color
  p.addParamValue('nsize',30); % 
  p.addParamValue('FontSize',10);
  p.addParamValue('LineWidth',1.5);
  p.addParamValue('EltNum',[]); % Element number 
  p.addParamValue('EltFaceColor','m');
  p.addParamValue('EltFaceAlpha',0.2);
  %p.addParamValue('EltEdgeColor','m');
  p.addParamValue('NumberingElts',true);
  p.addParamValue('view',[-80,12]);
  p.parse(varargin{:});
  R=p.Results;
  order=R.order;
  Oh=fc_hypermesh.OrthMesh(d,ones(1,d),'type','simplex','order',order);
  clf
  Oh.plotmesh('LineWidth',R.LineWidth)                            
  hold on
  Oh.plotnodes('vcolor',R.vcolor,'vsize',R.vsize,'ncolor',R.ncolor,'nsize',R.nsize)     
  c=1/20;
  if d==3
    D=[c;c;c];
    A=[0 1+c 0 1+c 0 1+c];
  elseif d==2
    D=[c;c];
    A=[0 1+c 0 1+c ];
  else
    D=[c;-c];
    A=[0 1+c -5*c 5*c];
  end
  
  fc_hypermesh.graphics.plotNodesNumber(Oh.Mesh.q,'D',D,'FontSize',R.FontSize,'EdgeColor','k')
  if R.NumberingElts
    Oh.ploteltsNumber('vLineColor','element','EdgeColor','element','FontWeight','bold')
  end
  %if d==3, view([124,9]);end
  
  
  if ~isempty(R.EltNum)
    q=Oh.Mesh.q;me=Oh.Mesh.me;
    Idx=fc_hypermesh.VerticesIdxSimpRef(d,order);
    idx=nchoosek(Idx,3);
    ME=[];
    for i=1:size(idx,1) 
      ME=[ME;me(idx(i,:),R.EltNum)'];
    end
    h=patch('Vertices',q','Faces',ME,'EdgeColor','k','FaceColor',R.EltFaceColor,'facealpha',R.EltFaceAlpha); 
  end
  if d==3, view(R.view);end
  if d>1, axis image;end
  axis(A)
  title(sprintf('Kuhn decomposition : d=%d, order=%d',d,R.order))
  if nargout==1, varargout{1}=Oh;end
end
